/* vim: set tabstop=8 softtabstop=2 shiftwidth=2 expandtab: */
/*
 *    Copyright (C) 2011 Fabian Deutsch
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License along
 *    with this program; if not, write to the Free Software Foundation, Inc.,
 *    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

public class ApplicationSettings : GLib.Object
{
    [Description (blurb = "Expand the window to the full screen?")]
    public bool is_fullscreen { 
        get; 
        set; 
        default = false; 
    }
    
    [Description (blurb = "Mute the incoming audio?")]
    public bool is_muted { 
        get; 
        set; 
        default = false; 
    }

    public string video_device {
      get;
      set;
      default = "/dev/video0";
    }

    [Description (blurb = "This factor determins the size of the transmitted video, based on the size of 1280x720. A larger factor requires over proportional more CPU but can lead to a crisper video.")]
    public double video_scale_factor {
        get;
        set;
        default = 0.25;
    }

    [Description (blurb = "This factor determins the quality of the transmitted video. A larger factor requires proptional more bandwidth.")]
    public double video_quality_factor {
        get;
        set;
        default = 0.75;
    }

    [Description (blurb = "This factor determins the frames per second of the transmitted video max 30. A larger factor requires proptional more bandwidth.")]
    public double video_fps_factor {
        get;
        set;
        default = 0.5;
    }

    [Description (blurb = "This is the requested framerate, it may be considered by the media.")]
    public double video_fps_request {
        get;
        set;
        default = -1;
    }

    [Description (blurb = "Shall a remote stream be received:")]
    public bool rtsp_client_enabled { 
        get; 
        set; 
        default = false; 
    }
    
    [Description (blurb = "The URI of the destination to connect to:")]
    public string? rtsp_client_uri { 
        get; 
        set; 
        default = "rtsp://127.0.0.1:8554"; 
    }

    [Description (blurb = "The URI of secondary destinations to connect to:")]
    public string[]? rtsp_secondary_client_uris { 
        get; 
        set; 
        default = new string[0]; 
    }

    [Description (blurb = "Should we provide a A/V stream?")]
    public bool rtsp_server_enabled { 
        get;
        set; 
        default = false;
    }

    [Description (blurb = "Password for authentication:")]
    public string? rtsp_server_auth_password { 
        get;
        set; 
        default = null;
    }

    [Description (blurb = "Published name:")]
    public string mdns_name { 
        get; 
        set; 
        default = "";
    }

    [Description (blurb = "Broadcast our presence?")]
    public bool mdns_enabled { 
        get; 
        set; 
        default = false;
    }

    [Description (blurb = "Broadcast domain:?")]
    public string? mdns_domain { 
        get;
        set; 
        default = null;
    }
    
    [Description (blurb = "Should IPv6 be used?")]
    public bool ipv6 {
      get;
      set;
      default = false;
    }

    public bool debug {
      get;
      set;
      default = false;
    }

    public bool use_advanced_video_preferences_dialog {
      get;
      set;
      default = false;
    }

    public ApplicationSettings ()
    {
        this.notify.connect ( (s,b) => {
            if (this.debug)
            {
              Value val = "";
              this.get_property (b.name, ref val);
              print (@"Settings changed: $(b.name) to '$(val.get_string ())'\n");
            }
        });
    }
}

